==> rapid_widgets_library-0.2.33.tar.gz: lib/custom-appBar.dart <==
import 'package:flutter/cupertino.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:flutter/material.dart';



Widget appbar(AppBarParams  appBarParams) {

  return (appBarParams.drawerPosition == 'Right') ? AppBar(
    elevation: (appBarParams.elevation!=null)?appBarParams.elevation:0,
    shadowColor: (appBarParams.shadowColor!=null)?appBarParams.shadowColor:Colors.transparent,
    backgroundColor: (appBarParams.backgroundColor!=null)?appBarParams.backgroundColor:Colors.transparent,
    shape: RoundedRectangleBorder(
      borderRadius: BorderRadius.vertical(
        bottom: Radius.circular((appBarParams.bottomRadius!=0)?appBarParams.bottomRadius:0),
      ),
    ),
    leading: (appBarParams.imageUrl!='null')?Padding(
      padding:  EdgeInsets.only(bottom: (appBarParams.bottomPadImage!=0)?appBarParams.bottomPadImage:0,
        top: (appBarParams.topPadImage!=null)?appBarParams.topPadImage:0,
        left: (appBarParams.leftPadImage!=null)?appBarParams.leftPadImage:0,
      ),
      child: Image(image: NetworkImage(appBarParams.imageUrl)),
    ):SizedBox.shrink(),
    title: (appBarParams.text!='')?Text(appBarParams.text,style: TextStyle(color: appBarParams.textColor),):SizedBox.shrink() ,
    actions: [
      SizedBox(width: 15,),
      (appBarParams.icon!=null)?Builder(
        builder: (context) => IconButton(
          icon: new Icon(appBarParams.icon,
              color: appBarParams.iconColor
          ),
          onPressed: () => Scaffold.of(context).openEndDrawer(),
        ),
      ):SizedBox.shrink(),
    ],
  ) : AppBar(
    elevation: (appBarParams.elevation != null) ? appBarParams.elevation : 0,
    shadowColor: (appBarParams.shadowColor != null)
        ? appBarParams.shadowColor
        : Colors.transparent,
    backgroundColor: (appBarParams.backgroundColor != null) ? appBarParams
        .backgroundColor : Colors.transparent,
    shape: RoundedRectangleBorder(
      borderRadius: BorderRadius.vertical(
        bottom: Radius.circular(
            (appBarParams.bottomRadius != 0) ? appBarParams.bottomRadius : 0),
      ),
    ),
    leading: (appBarParams.icon != null) ? Builder(
      builder: (context) =>
          IconButton(
            icon: new Icon(appBarParams.icon,
                color: appBarParams.iconColor
            ),
            onPressed: () => Scaffold.of(context).openDrawer(),
          ),
    ) : SizedBox.shrink(),
    title: Row(
      mainAxisAlignment: MainAxisAlignment.spaceAround,
      children: [
        (appBarParams.imageUrl!='null')?Padding(
          padding:  EdgeInsets.only(
            bottom: (appBarParams.bottomPadImage!=0)?appBarParams.bottomPadImage:0,
            top: (appBarParams.topPadImage!=null)?appBarParams.topPadImage:0,
            left: (appBarParams.leftPadImage!=null)?appBarParams.leftPadImage:0,
            right: (appBarParams.rightPadImage!=null)?appBarParams.rightPadImage:0,
          ),
          child: Container(
            height: 50,
            width: 50,
            child: Image(
                image: NetworkImage(appBarParams.imageUrl)),
          ),
        ):SizedBox.shrink(),
        SizedBox(width: 10,),
        (appBarParams.text!='null')?Text(appBarParams.text,style: TextStyle(color: appBarParams.textColor),):SizedBox.shrink(),
      ],
    ) ,

  );
}




/*

(appBarParams.imageUrl!='')?Padding(
padding:  EdgeInsets.only(bottom: (appBarParams.bottomPadImage!=0)?appBarParams.bottomPadImage:0,
top: (appBarParams.topPadImage!=null)?appBarParams.topPadImage:0,
left: (appBarParams.leftPadImage!=null)?appBarParams.leftPadImage:0,
),
child: Image(image: NetworkImage(appBarParams.imageUrl)),
):SizedBox.shrink(),*/

==> rapid_widgets_library-0.2.34.tar.gz: lib/custom-appBar.dart <==
import 'package:flutter/cupertino.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:flutter/material.dart';



Widget appbar(AppBarParams  appBarParams) {

  return (appBarParams.drawerPosition == 'Right') ? AppBar(
    elevation: (appBarParams.elevation!=null)?appBarParams.elevation:0,
    shadowColor: (appBarParams.shadowColor!=null)?appBarParams.shadowColor:Colors.transparent,
    backgroundColor: (appBarParams.backgroundColor!=null)?appBarParams.backgroundColor:Colors.transparent,
    shape: RoundedRectangleBorder(
      borderRadius: BorderRadius.vertical(
        bottom: Radius.circular((appBarParams.bottomRadius!=0)?appBarParams.bottomRadius:0),
      ),
    ),
    leading: (appBarParams.imageUrl!='null')?Padding(
      padding:  EdgeInsets.only(bottom: (appBarParams.bottomPadImage!=0)?appBarParams.bottomPadImage:0,
        top: (appBarParams.topPadImage!=null)?appBarParams.topPadImage:0,
        left: (appBarParams.leftPadImage!=null)?appBarParams.leftPadImage:0,
      ),
      child: Image(image: NetworkImage(appBarParams.imageUrl)),
    ):SizedBox.shrink(),
    title: (appBarParams.text!='')?Text(appBarParams.text,style: TextStyle(color: appBarParams.textColor),):SizedBox.shrink() ,
    actions: [
      SizedBox(width: 15,),
      (appBarParams.icon1!=null)?Builder(
        builder: (context) => IconButton(
          icon: new Icon(appBarParams.icon1,
              color: appBarParams.iconColor
          ),
          onPressed: () => Scaffold.of(context).openEndDrawer(),
        ),
      ):SizedBox.shrink(),
    ],
  ) : AppBar(
    elevation: (appBarParams.elevation != null) ? appBarParams.elevation : 0,
    shadowColor: (appBarParams.shadowColor != null)
        ? appBarParams.shadowColor
        : Colors.transparent,
    backgroundColor: (appBarParams.backgroundColor != null) ? appBarParams
        .backgroundColor : Colors.transparent,
    shape: RoundedRectangleBorder(
      borderRadius: BorderRadius.vertical(
        bottom: Radius.circular(
            (appBarParams.bottomRadius != 0) ? appBarParams.bottomRadius : 0),
      ),
    ),
    leading: (appBarParams.icon1 != null) ? Builder(
      builder: (context) =>
          IconButton(
            icon: new Icon(appBarParams.icon1,
                color: appBarParams.iconColor
            ),
            onPressed: () => Scaffold.of(context).openDrawer(),
          ),
    ) : SizedBox.shrink(),
    title: Padding(
      padding:  EdgeInsets.only(
        bottom: (appBarParams.bottomPadImage!=null)?appBarParams.bottomPadImage:0,
        top: (appBarParams.topPadImage!=null)?appBarParams.topPadImage:0,
        left: (appBarParams.leftPadImage!=null)?appBarParams.leftPadImage:0,
        right: (appBarParams.rightPadImage!=null)?appBarParams.rightPadImage:0,
      ),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.start,
        children: [

          (appBarParams.imageUrl!='null')?Container(
            height: 50,
            width: 50,
            child: Image(
                image: NetworkImage(appBarParams.imageUrl)),
          ):SizedBox.shrink(),
          (appBarParams.imageUrl!='null')?SizedBox(width: 10,):SizedBox.shrink(),
          (appBarParams.text!='null')?
          Flexible(child: Text(appBarParams.text,style: TextStyle(color: appBarParams.textColor))):SizedBox.shrink(),
        ],
      ),
    ) ,
actions: [
  (appBarParams.icon2!=null)?SizedBox(width: 10,):SizedBox.shrink(),
  (appBarParams.icon2!=null)?Icon(appBarParams.icon2, color: appBarParams.iconColor??Colors.grey,size: 18,):SizedBox.shrink(),
  (appBarParams.icon3!=null)?SizedBox(width: 10,):SizedBox.shrink(),
  (appBarParams.icon3!=null)?Icon(appBarParams.icon3, color: appBarParams.iconColor??Colors.grey,size: 18,):SizedBox.shrink(),
  (appBarParams.icon4!=null)?SizedBox(width: 10,):SizedBox.shrink(),
  (appBarParams.icon4!=null)?Icon(appBarParams.icon4, color: appBarParams.iconColor??Colors.grey,size: 18,):SizedBox.shrink(),
  SizedBox(width: 25,),
],

  );
}




/*

(appBarParams.imageUrl!='')?Padding(
padding:  EdgeInsets.only(bottom: (appBarParams.bottomPadImage!=0)?appBarParams.bottomPadImage:0,
top: (appBarParams.topPadImage!=null)?appBarParams.topPadImage:0,
left: (appBarParams.leftPadImage!=null)?appBarParams.leftPadImage:0,
),
child: Image(image: NetworkImage(appBarParams.imageUrl)),
):SizedBox.shrink(),*/
